@@ -253,7 +253,7 @@ void dviRenderer::drawPage(RenderedDocumentPagePixmap* page)
 void dviRenderer::getText(RenderedDocumentPagePixmap* page)
 {
   bool postscriptBackup = _postscript;
-  // Disable postscript-specials temporarely to speed up text extraction.
+  // Disable postscript-specials temporarily to speed up text extraction.
   _postscript = false;
 
   drawPage(page);
@@ -280,7 +280,7 @@ void dviRenderer::showThatSourceInformationIsPresent()
 
     QWidget *topcontents = new QWidget (&dialog);
     QVBoxLayout *topcontentsVBoxLayout = new QVBoxLayout(topcontents);
-    topcontentsVBoxLayout->setMargin(0);
+    topcontentsVBoxLayout->setContentsMargins(0, 0, 0, 0);
     topcontentsVBoxLayout->setSpacing(KDialog::spacingHint()*2);
     topcontentsVBoxLayout->setMargin(KDialog::marginHint()*2);
 
