@@ -20,7 +20,7 @@ class EPubGenerator : public Okular::TextDocumentGenerator
   ~EPubGenerator();
 
   // [INHERITED] reparse configuration
-  void addPages( KConfigDialog* dlg );
+  void addPages( KConfigDialog* dlg ) override;
 };
 
 #endif
