@@ -12,6 +12,8 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#include <memory>
+
 #include "generator_pdf.h"
 
 // qt/kde includes
@@ -26,6 +28,7 @@
 #include <qstack.h>
 #include <qtemporaryfile.h>
 #include <qtextstream.h>
+#include <QComboBox>
 #include <QPrinter>
 #include <QPainter>
 #include <QTimer>
@@ -53,6 +56,9 @@
 #include <config-okular-poppler.h>
 
 #include <poppler-media.h>
+#ifdef HAVE_POPPLER_0_73
+#include <poppler-version.h>
+#endif
 
 #include "debug_pdf.h"
 #include "annots.h"
@@ -73,8 +79,26 @@ static const int defaultPageHeight = 842;
 class PDFOptionsPage : public QWidget
 {
     Q_OBJECT
+public slots:
+       void enableOrDisableScaleMode()
+       {
+           m_scaleMode->setEnabled ( m_forceRaster->isChecked() );
+
+           if ( m_forceRaster->isChecked() ) {
+               m_scaleMode->setToolTip( i18n( "Scaling mode for the printed pages" ) );
+           } else {
+               m_scaleMode->setToolTip( i18n( "Select rasterization to enable this!" ) );
+           }
+       }
 
    public:
+       enum ScaleMode {
+            FitToPrintableArea,
+            FitToPage,
+            None
+       };
+       Q_ENUM(ScaleMode)
+
        PDFOptionsPage()
        {
            setWindowTitle( i18n( "PDF Options" ) );
@@ -87,8 +111,26 @@ class PDFOptionsPage : public QWidget
            m_forceRaster->setToolTip(i18n("Rasterize into an image before printing"));
            m_forceRaster->setWhatsThis(i18n("Forces the rasterization of each page into an image before printing it. This usually gives somewhat worse results, but is useful when printing documents that appear to print incorrectly."));
            layout->addWidget(m_forceRaster);
+
+           QWidget* formWidget = new QWidget(this);
+           QFormLayout* printBackendLayout = new QFormLayout(formWidget);
+
+           m_scaleMode = new QComboBox;
+           m_scaleMode->insertItem(FitToPrintableArea, i18n("Fit to printable area"), FitToPrintableArea);
+           m_scaleMode->insertItem(FitToPage, i18n("Fit to full page"), FitToPage);
+           m_scaleMode->insertItem(None, i18n("None; print original size"), None);
+           m_scaleMode->setToolTip(i18n("Select rasterization to enable this!"));
+           printBackendLayout->addRow(i18n("Scale mode:"), m_scaleMode);
+
+           layout->addWidget(formWidget);
+
            layout->addStretch(1);
 
+           // Enable scaleMode only if the file is to be rasterized before printing
+           m_scaleMode->setEnabled( false );
+
+           connect( m_forceRaster, &QCheckBox::stateChanged, this, &PDFOptionsPage::enableOrDisableScaleMode );
+
 #if defined(Q_OS_WIN) && !defined HAVE_POPPLER_0_60
            m_printAnnots->setVisible( false );
 #endif
@@ -115,9 +157,15 @@ class PDFOptionsPage : public QWidget
            m_forceRaster->setChecked( forceRaster );
        }
 
+       ScaleMode scaleMode() const
+       {
+           return m_scaleMode->currentData().value<ScaleMode>();
+       }
+
     private:
         QCheckBox *m_printAnnots;
         QCheckBox *m_forceRaster;
+        QComboBox *m_scaleMode;
 };
 
 
@@ -331,7 +379,7 @@ Okular::Action* createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
     {
         case Poppler::Link::None:
         break;
-
+        
         case Poppler::Link::Goto:
         {
             popplerLinkGoto = static_cast<const Poppler::LinkGoto *>(popplerLink);
@@ -475,6 +523,9 @@ Okular::Action* createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
         }
         break;
 #endif
+        
+        case Poppler::Link::OCGState:
+            Q_UNREACHABLE();
     }
 
 #ifdef HAVE_POPPLER_0_64
@@ -1288,11 +1339,13 @@ bool PDFGenerator::print( QPrinter& printer )
 {
     bool printAnnots = true;
     bool forceRasterize = false;
+    PDFOptionsPage::ScaleMode scaleMode = PDFOptionsPage::FitToPrintableArea;
 
     if ( pdfOptionsPage )
     {
         printAnnots = pdfOptionsPage->printAnnots();
         forceRasterize = pdfOptionsPage->printForceRaster();
+        scaleMode = pdfOptionsPage->scaleMode();
     }
 
 #ifdef Q_OS_WIN
@@ -1314,6 +1367,11 @@ bool PDFGenerator::print( QPrinter& printer )
     if ( forceRasterize && printAnnots)
     {
 #endif
+
+        // If requested, scale to full page instead of the printable area
+        if ( scaleMode == PDFOptionsPage::FitToPage )
+            printer.setFullPage( true );
+
     QPainter painter;
     painter.begin(&printer);
 
@@ -1327,17 +1385,33 @@ bool PDFGenerator::print( QPrinter& printer )
 
         const int page = pageList.at( i ) - 1;
         userMutex()->lock();
-        Poppler::Page *pp = pdfdoc->page( page );
+        std::unique_ptr<Poppler::Page> pp( pdfdoc->page( page ) );
         if (pp)
         {
+                QSizeF pageSize = pp->pageSizeF();        // Unit is 'points' (i.e., 1/72th of an inch)
+                QRect painterWindow = painter.window();   // Unit is 'QPrinter::DevicePixel'
+
+                // Default: no scaling at all, but we need to go from DevicePixel units to 'points'
+                // Warning: We compute the horizontal scaling, and later assume that the vertical scaling will be the same.
+                double scaling = printer.paperRect(QPrinter::DevicePixel).width() / printer.paperRect(QPrinter::Point).width();
+
+                if ( scaleMode != PDFOptionsPage::None )
+                {
+                     // Get the two scaling factors needed to fit the page onto paper horizontally or vertically
+                     auto horizontalScaling = painterWindow.width() / pageSize.width();
+                     auto verticalScaling   = painterWindow.height() / pageSize.height();
+
+                     // We use the smaller of the two for both directions, to keep the aspect ratio
+                     scaling = std::min(horizontalScaling, verticalScaling);
+                }
+
 #ifdef Q_OS_WIN
             QImage img = pp->renderToImage(  printer.physicalDpiX(), printer.physicalDpiY() );
 #else
             // UNIX: Same resolution as the postscript rasterizer; see discussion at https://git.reviewboard.kde.org/r/130218/
             QImage img = pp->renderToImage( 300, 300 );
 #endif
-            painter.drawImage( painter.window(), img, QRectF(0, 0, img.width(), img.height()) );
-            delete pp;
+            painter.drawImage( QRectF( QPointF( 0, 0 ), scaling * pp->pageSizeF() ), img );
         }
         userMutex()->unlock();
     }
@@ -1492,6 +1566,30 @@ QVariant PDFGenerator::metaData( const QString & key, const QVariant & option )
         return QVariant::fromValue<QVector<int>>(pdfdoc->formCalculateOrder());
 #endif
     }
+    else if ( key == QLatin1String("GeneratorExtraDescription") )
+    {
+#ifdef HAVE_POPPLER_0_73
+        if (Poppler::Version::string() == POPPLER_VERSION) {
+            return i18n("Using Poppler %1", Poppler::Version::string());
+        } else {
+            return i18n("Using Poppler %1\n\nBuilt against Poppler %2", Poppler::Version::string(), POPPLER_VERSION);
+        }
+#endif
+    }
+    else if ( key == QLatin1String("IsDigitallySigned") )
+    {
+        const Okular::Document *doc = document();
+        uint numPages = doc->pages();
+        for ( uint i = 0; i < numPages; i++ )
+        {
+            foreach ( Okular::FormField *f, doc->page( i )->formFields() )
+            {
+                if ( f->type() == Okular::FormField::FormSignature )
+                    return true;
+            }
+        }
+        return false;
+    }
     return QVariant();
 }
 
@@ -1876,6 +1974,10 @@ void PDFGenerator::addFormFields( Poppler::Page * popplerPage, Okular::Page * pa
             case Poppler::FormField::FormChoice:
                 of = new PopplerFormFieldChoice( static_cast<Poppler::FormFieldChoice*>( f ) );
                 break;
+            case Poppler::FormField::FormSignature: {
+                of = new PopplerFormFieldSignature( static_cast<Poppler::FormFieldSignature*>( f ) );
+                break;
+            }
             default: ;
         }
         if ( of )
@@ -1920,7 +2022,7 @@ bool PDFGenerator::save( const QString &fileName, SaveOptions options, QString *
 {
     Q_UNUSED(errorText);
     Poppler::PDFConverter *pdfConv = pdfdoc->pdfConverter();
-
+    
     pdfConv->setOutputFileName( fileName );
     if ( options & SaveChanges )
         pdfConv->setPDFOptions( pdfConv->pdfOptions() | Poppler::PDFConverter::WithChanges );
